#Completed in R version 4.2.1 (2022-06-23 ucrt) [platform: x86_64-w64-mingw32]
#Including the following package:
library(dplyr) #package version 1.0.10

#2.3. Descriptive Variables

studysample2 <- studysample2 %>%
  mutate(
    age_w8 = case_when(
      yrbirth > 0 & int_year > 0 & mobirth > 0 & int_month > 0 ~ (int_year + (int_month-1)/12) - (yrbirth + (mobirth-1)/12),
      yrbirth > 0 & int_year > 0 ~ int_year - yrbirth), #less precise estimate for those without a month of birth
    agecat_w8 = case_when(
      age_w8 >= 65 & age_w8 < 75 ~ 1,
      age_w8 >= 75 & age_w8 < 85 ~ 2,
      age_w8 >= 85 ~ 3),
    female = case_when(
      gender == 1 ~ 0,
      gender == 2 ~ 1),
    educationcat_w8 = case_when( #education ISCED-1997 score
      isced1997r_w8 >= 0 & isced1997r_w8 <= 2 ~ 1,
      isced1997r_w8 == 3 | isced1997r_w8 == 4 ~ 2,
      isced1997r_w8 == 5 | isced1997r_w8 == 6 ~ 3), #Excluded 95 (still in school) and 97 (other).
    functindependent3_w8 = case_when( #function interdependently in 3 selected IADLs: telephone calls, medication, money
      ph049d1_w8 >= 0 & (ph049d10_w8 + ph049d11_w8 + ph049d13_w8) >= 1 ~ 0,
      ph049d1_w8 >= 0 ~ 1),
    galimod_w8 = case_when( #activities limited by health
      ph005_w8 == 3 ~ 0, #none
      ph005_w8 == 2 ~ 1,
      ph005_w8 == 1 ~ 3), #severe
    livesalone_w8 = case_when( #lives alone
      hhsize >= 2 ~ 0, 
      hhsize == 1 ~ 1),
    ep005mod_w8 = case_when( #employed
      nursinghome == 1 ~ 0, 
      ep005_w8 == 1 | ep005_w8 >= 3 ~ 0,
      ep005_w8 == 2 ~ 1),
    multimorbidity_w8 = case_when( #multimorbidity
      ph006d1_w8 + ph006d2_w8 + ph006d3_w8 + ph006d4_w8 + ph006d5_w8 + ph006d6_w8 + 
        ph006d10_w8 + ph006d11_w8 + ph006d12_w8 + ph006d13_w8 + ph006d14_w8 + ph006d15_w8 + ph006d18_w8 + 
        ph006d19_w8 + ph006d20_w8 + ph006d21_w8 < 2 ~ 0, #sum out of 16 (dementia excluded)
      ph006d1_w8 + ph006d2_w8 + ph006d3_w8 + ph006d4_w8 + ph006d5_w8 + ph006d6_w8 + 
        ph006d10_w8 + ph006d11_w8 + ph006d12_w8 + ph006d13_w8 + ph006d14_w8 + ph006d15_w8 + ph006d18_w8 + 
        ph006d19_w8 + ph006d20_w8 + ph006d21_w8 >= 2 ~ 1), #sum out of 16 (dementia excluded)
    eyesight_w8 = case_when( #eyesight fair/poor
      ph043_w8 >= 0 & ph043_w8 <= 3 & ph044_w8 >= 0 & ph044_w8 <=3 ~ 0,
      ph043_w8 >= 4 | ph044_w8 >=4 ~ 1), #Two eyesight questions merged (distant/close).
    hearing_w8 = case_when( #hearing fair/poor
      ph046_w8 >= 0 & ph046_w8 <= 3 ~ 0,
      ph046_w8 >= 4 ~ 1),
    sphusmod_w8 = case_when( #self-rated health fair/poor
      sphus_w8 >= 0 & sphus_w8 <= 3 ~ 0,
      sphus_w8 >= 4 ~ 1),
    euro9wt_w8 = case_when( #weighted variable for the SHARE-FI
      gender == 2 & euro9_w8 >= 0 ~ (2.077707 * euro9_w8 - 0.757295) * 0.4088, 
      gender == 1 & euro9_w8 >= 0 ~ (2.280336 * euro9_w8 - 0.592393) * 0.3762),
    euro8wt_w8 = case_when( #weighted variable for the SHARE-FI
      gender == 2 & euro8_w8 >= 0 ~ (3.341539 * euro8_w8 - 0.332289) * 0.3325, 
      gender == 1 & euro8_w8 >= 0 ~ (4.058274 * euro8_w8 - 0.263501) * 0.3130),
    maxgripwt_w8 = case_when( #weighted variable for the SHARE-FI
      gender == 2 & maxgrip_w8 >= 0 ~ (0.132827 * maxgrip_w8 - 3.534515) * -0.4910, 
      gender == 1 & maxgrip_w8 >= 0 ~ (0.092326 * maxgrip_w8 - 3.986646) * 0.4653),
    ph048d1d5_w8 = case_when( #walking difficulty for the SHARE-FI
      ph048d1_w8 == 0 & ph048d5_w8 == 0 ~ 0,
      ph048d1_w8 == 1 | ph048d5_w8 == 1 ~ 1),
    ph048d1d5wt_w8 = case_when( #weighted variable for the SHARE-FI
      gender == 2 & ph048d1d5_w8 >= 0 ~ (2.627085 * ph048d1d5_w8 - 0.461808) * 0.6012, 
      gender == 1 & ph048d1d5_w8 >= 0 ~ (3.098226 * ph048d1d5_w8 - 0.365971) * 0.6146),
    br016wt_w8 = case_when( #weighted variable for the SHARE-FI
      gender == 2 & br016_w8 >= 0 ~ (0.918866 * br016_w8 - 1.523633) * 0.4818, 
      gender == 1 & br016_w8 >= 0 ~ (1.005942 * br016_w8 - 1.571803) * 0.4680),
    sharefiscore_w8 = rowSums(cbind(euro8wt_w8, euro9wt_w8, maxgripwt_w8, ph048d1d5wt_w8, br016wt_w8), na.rm=TRUE),
    sharefifrail_w8 = case_when( #physical frailty (SHARE-FI) with gender-specific cut-offs
      gender == 2 & sharefiscore_w8 < 0.3151361243 ~ 0,
      gender == 2 & sharefiscore_w8 < 2.1301121973 ~ 1, 
      gender == 2 & sharefiscore_w8 < 6 ~ 2,
      gender == 1 & sharefiscore_w8 < 1.211878526 ~ 0,
      gender == 1 & sharefiscore_w8 < 3.0052612772 ~ 1, 
      gender == 1 & sharefiscore_w8 < 7 ~ 2),
    hc012mod_w8 = case_when( #hospitalisation
      hc012_w8 == 5 ~ 0,
      hc012_w8 == 1 ~ 1))
