#Completed in R version 4.2.1 (2022-06-23 ucrt) [platform: x86_64-w64-mingw32]
#Including the following package:
library(dplyr) #package version 1.0.10

#2.4. Cognitive Classifications

##Dementia, SMC, and IADL questions
studysample2 <- studysample2 %>%
  mutate(
    dementiaquestion_w8 = case_when( #self-reported memory disease diagnosis
      ph006d16_w8 == 0 ~ 0,
      ph006d16_w8 == 1 ~ 1),
    smcquestion_w8 = case_when( #self-rated memory fair/poor
      cf103_w8 >= 1 & cf103_w8 <= 3 ~ 0,
      cf103_w8 >= 4 & cf103_w8 <= 5 ~ 1),
    functindependent3_w8 = case_when( #function interdependently in IADLs
      ph049d1_w8 >= 0 & (ph049d10_w8 + ph049d11_w8 + ph049d13_w8) >= 1 ~ 0, #difficulty with any of the 3 selected IADLs
      ph049d1_w8 >= 0 ~ 1))

##Age- and education- specific cut-offs for dementia and MCI
cutoffs <- aggregate(cogbattery_w8 ~ agecat_w8 + educationcat_w8, data = studysample2, FUN = length)
cutoffs$mci_cutoff <- aggregate(cogbattery_w8 ~ agecat_w8 + educationcat_w8, data = studysample2, FUN = mean)[3]-aggregate(cogbattery_w8 ~ agecat_w8 + educationcat_w8, data = studysample2, FUN = sd)[3]
cutoffs$dementia_cutoff <- aggregate(cogbattery_w8 ~ agecat_w8 + educationcat_w8, data = studysample2, FUN = mean)[3]-2*aggregate(cogbattery_w8 ~ agecat_w8 + educationcat_w8, data = studysample2, FUN = sd)[3]
studysample2 <- left_join(studysample2,
                          cutoffs %>% select(agecat_w8, educationcat_w8, mci_cutoff, dementia_cutoff), 
                          by = c("educationcat_w8", "agecat_w8"), all.x = TRUE)
studysample2 <- studysample2 %>%
  mutate(
    cutoff_cat = case_when(
      cogbattery_w8 <= dementia_cutoff ~ 1, 
      (cogbattery_w8 > dementia_cutoff) & (cogbattery_w8 <= mci_cutoff) ~ 2,
      cogbattery_w8 > mci_cutoff ~ 3),
    dementia_cutoff_cat = case_when(
      cogbattery_w8 <= dementia_cutoff ~ 1,
      cogbattery_w8 > dementia_cutoff ~ 0),
    mci_cutoff_cat = case_when(
      (cogbattery_w8 > dementia_cutoff) & (cogbattery_w8 <= mci_cutoff) ~ 1,
      (cogbattery_w8 <= dementia_cutoff) | (cogbattery_w8 > mci_cutoff) ~ 0),
    nc_cutoff_cat = case_when(
      cogbattery_w8 > mci_cutoff ~ 1,
      cogbattery_w8 <= mci_cutoff ~ 0))

##All possible cognitive combinations
studysample2 <- studysample2 %>%
  mutate(
    cognitivegroups_all_w8 = case_when(
      dementiaquestion_w8 == 1 & cutoff_cat == 1 & functindependent3_w8 == 0 ~ 1,
      dementiaquestion_w8 == 1 & cutoff_cat == 1 & functindependent3_w8 == 1 ~ 2,
      dementiaquestion_w8 == 1 & cutoff_cat == 2 & functindependent3_w8 == 0 ~ 3,
      dementiaquestion_w8 == 1 & cutoff_cat == 2 & functindependent3_w8 == 1 ~ 4,
      dementiaquestion_w8 == 1 & cutoff_cat == 3 & functindependent3_w8 == 0 ~ 5,
      dementiaquestion_w8 == 1 & cutoff_cat == 3 & functindependent3_w8 == 1 ~ 6,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent3_w8 == 0 & smcquestion_w8 == 1 ~ 7,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent3_w8 == 0 & smcquestion_w8 == 0 ~ 8,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent3_w8 == 1 & smcquestion_w8 == 1 ~ 9,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent3_w8 == 1 & smcquestion_w8 == 0 ~ 10,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent3_w8 == 0 & smcquestion_w8 == 1 ~ 11,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent3_w8 == 0 & smcquestion_w8 == 0 ~ 12,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent3_w8 == 1 & smcquestion_w8 == 1 ~ 13,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent3_w8 == 1 & smcquestion_w8 == 0 ~ 14,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent3_w8 == 0 & smcquestion_w8 == 1 ~ 15,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent3_w8 == 0 & smcquestion_w8 == 0 ~ 16,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent3_w8 == 1 & smcquestion_w8 == 1 ~ 17,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent3_w8 == 1 & smcquestion_w8 == 0 ~ 18))

##Diagnostic groups (cognitive groups with unclear classifications recoded as NA)
studysample2 <- studysample2 %>%
  mutate(
    cognitivegroups_w8 = case_when(
      cognitivegroups_all_w8 == 1 ~ 1,
      cognitivegroups_all_w8 == 2 ~ NA_real_,
      cognitivegroups_all_w8 == 3 ~ 1,
      cognitivegroups_all_w8 == 4 ~ 2,
      cognitivegroups_all_w8 == 5 ~ 1,
      cognitivegroups_all_w8 == 6 ~ 2,
      cognitivegroups_all_w8 == 7 ~ 1,
      cognitivegroups_all_w8 == 8 ~ 1,
      cognitivegroups_all_w8 == 9 ~ NA_real_,
      cognitivegroups_all_w8 == 10 ~ NA_real_,
      cognitivegroups_all_w8 == 11 ~ NA_real_,
      cognitivegroups_all_w8 == 12 ~ NA_real_,
      cognitivegroups_all_w8 == 13 ~ 2,
      cognitivegroups_all_w8 == 14 ~ NA_real_,
      cognitivegroups_all_w8 == 15 ~ NA_real_,
      cognitivegroups_all_w8 == 16 ~ NA_real_,
      cognitivegroups_all_w8 == 17 ~ 3,
      cognitivegroups_all_w8 == 18 ~ 4))

##Diagnostic comparisons
studysample2 <- studysample2 %>%
  mutate(
    D_MCI_v_SMC_NC = case_when(
      cognitivegroups_w8 == 1 | cognitivegroups_w8 == 2 ~ 1,
      cognitivegroups_w8 == 3 | cognitivegroups_w8 == 4 ~ 0),
    D_MCI_v_NC = case_when(
      cognitivegroups_w8 == 1 | cognitivegroups_w8 == 2 ~ 1,
      cognitivegroups_w8 == 4 ~ 0),
    MCI_v_D = case_when(
      cognitivegroups_w8 == 2 ~ 1,
      cognitivegroups_w8 == 1 ~ 0),
    MCI_v_SMC_NC = case_when(
      cognitivegroups_w8 == 2 ~ 1,
      cognitivegroups_w8 == 3 | cognitivegroups_w8 == 4  ~ 0),
    MCI_v_NC = case_when(
      cognitivegroups_w8 == 2 ~ 1,
      cognitivegroups_w8 == 4  ~ 0),
    D_v_MCI_SMC_NC = case_when(
      cognitivegroups_w8 == 1 ~ 1,
      cognitivegroups_w8 == 2 | cognitivegroups_w8 == 3 | cognitivegroups_w8 == 4  ~ 0))


#2.1 Sample selection

##2.2.3 No unclear diagnostic categories (primary sample)
sample_primary <- studysample2[!(is.na(studysample2$cognitivegroups_w8)),] #Sample used in all primary analyses


#Variables for sensitivity analyses

##Alternative functional independence variable
studysample2 <- studysample2 %>%
  mutate(
    functindependent9v1_w8 = case_when( #function interdependently in all 9 IADLs 
      ph049d1_w8 >= 0 & (ph049d7_w8 + ph049d8_w8 + ph049d9_w8 + ph049d10_w8 + ph049d11_w8 + 
                           ph049d12_w8 + ph049d13_w8 + ph049d14_w8 + ph049d15_w8) >= 1 ~ 0, #difficulty with any of the 9 IADLs
      ph049d1_w8 >= 0 ~ 1), #remainder do not have difficulty
    functindependent9v2_w8 = case_when( #function interdependently in IADLs
      ph049d1_w8 >= 0 & (ph049d7_w8 + ph049d8_w8 + ph049d10_w8 + ph049d11_w8 + ph049d13_w8) >= 1 ~ 0,
      ph049d9_w8 == 1 & (ph048d1_w8 == 0 & ph048d9_w8 == 0) ~ 0, #shopping [walk 100m, lift 5kg]
      ph049d12_w8 == 1 & (ph048d6_w8 == 0) ~ 0, #work house/garden [stooping]
      ph049d14_w8 == 1 & (ph048d1_w8 == 0) ~ 0, #leaving independently [walk 100m]
      ph049d15_w8 == 1 & (ph048d6_w8 == 0) ~ 0, #laundry [stooping]      
      ph049d1_w8 >= 0 ~ 1)) #remainder do not have difficulty

##Alternative cognitive combinations
studysample2 <- studysample2 %>%
  mutate(
    cognitivegroupsS1_all_w8 = case_when(#positive responses to self-reported dementia question excluded
      dementiaquestion_w8 == 1 & cutoff_cat == 1 & functindependent3_w8 == 0 ~ NA_real_,
      dementiaquestion_w8 == 1 & cutoff_cat == 1 & functindependent3_w8 == 1 ~ NA_real_,
      dementiaquestion_w8 == 1 & cutoff_cat == 2 & functindependent3_w8 == 0 ~ NA_real_,
      dementiaquestion_w8 == 1 & cutoff_cat == 2 & functindependent3_w8 == 1 ~ NA_real_,
      dementiaquestion_w8 == 1 & cutoff_cat == 3 & functindependent3_w8 == 0 ~ NA_real_,
      dementiaquestion_w8 == 1 & cutoff_cat == 3 & functindependent3_w8 == 1 ~ NA_real_,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent3_w8 == 0 & smcquestion_w8 == 1 ~ 7,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent3_w8 == 0 & smcquestion_w8 == 0 ~ 8,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent3_w8 == 1 & smcquestion_w8 == 1 ~ 9,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent3_w8 == 1 & smcquestion_w8 == 0 ~ 10,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent3_w8 == 0 & smcquestion_w8 == 1 ~ 11,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent3_w8 == 0 & smcquestion_w8 == 0 ~ 12,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent3_w8 == 1 & smcquestion_w8 == 1 ~ 13,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent3_w8 == 1 & smcquestion_w8 == 0 ~ 14,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent3_w8 == 0 & smcquestion_w8 == 1 ~ 15,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent3_w8 == 0 & smcquestion_w8 == 0 ~ 16,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent3_w8 == 1 & smcquestion_w8 == 1 ~ 17,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent3_w8 == 1 & smcquestion_w8 == 0 ~ 18),
    cognitivegroupsS2_all_w8 = case_when(
      dementiaquestion_w8 == 1 & cutoff_cat == 1 & functindependent9v1_w8 == 0 ~ 1,
      dementiaquestion_w8 == 1 & cutoff_cat == 1 & functindependent9v1_w8 == 1 ~ 2,
      dementiaquestion_w8 == 1 & cutoff_cat == 2 & functindependent9v1_w8 == 0 ~ 3,
      dementiaquestion_w8 == 1 & cutoff_cat == 2 & functindependent9v1_w8 == 1 ~ 4,
      dementiaquestion_w8 == 1 & cutoff_cat == 3 & functindependent9v1_w8 == 0 ~ 5,
      dementiaquestion_w8 == 1 & cutoff_cat == 3 & functindependent9v1_w8 == 1 ~ 6,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent9v1_w8 == 0 & smcquestion_w8 == 1 ~ 7,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent9v1_w8 == 0 & smcquestion_w8 == 0 ~ 8,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent9v1_w8 == 1 & smcquestion_w8 == 1 ~ 9,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent9v1_w8 == 1 & smcquestion_w8 == 0 ~ 10,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent9v1_w8 == 0 & smcquestion_w8 == 1 ~ 11,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent9v1_w8 == 0 & smcquestion_w8 == 0 ~ 12,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent9v1_w8 == 1 & smcquestion_w8 == 1 ~ 13,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent9v1_w8 == 1 & smcquestion_w8 == 0 ~ 14,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent9v1_w8 == 0 & smcquestion_w8 == 1 ~ 15,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent9v1_w8 == 0 & smcquestion_w8 == 0 ~ 16,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent9v1_w8 == 1 & smcquestion_w8 == 1 ~ 17,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent9v1_w8 == 1 & smcquestion_w8 == 0 ~ 18),
    cognitivegroupsS3_all_w8 = case_when(
      dementiaquestion_w8 == 1 & cutoff_cat == 1 & functindependent9v2_w8 == 0 ~ 1,
      dementiaquestion_w8 == 1 & cutoff_cat == 1 & functindependent9v2_w8 == 1 ~ 2,
      dementiaquestion_w8 == 1 & cutoff_cat == 2 & functindependent9v2_w8 == 0 ~ 3,
      dementiaquestion_w8 == 1 & cutoff_cat == 2 & functindependent9v2_w8 == 1 ~ 4,
      dementiaquestion_w8 == 1 & cutoff_cat == 3 & functindependent9v2_w8 == 0 ~ 5,
      dementiaquestion_w8 == 1 & cutoff_cat == 3 & functindependent9v2_w8 == 1 ~ 6,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent9v2_w8 == 0 & smcquestion_w8 == 1 ~ 7,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent9v2_w8 == 0 & smcquestion_w8 == 0 ~ 8,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent9v2_w8 == 1 & smcquestion_w8 == 1 ~ 9,
      dementiaquestion_w8 == 0 & cutoff_cat == 1 & functindependent9v2_w8 == 1 & smcquestion_w8 == 0 ~ 10,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent9v2_w8 == 0 & smcquestion_w8 == 1 ~ 11,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent9v2_w8 == 0 & smcquestion_w8 == 0 ~ 12,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent9v2_w8 == 1 & smcquestion_w8 == 1 ~ 13,
      dementiaquestion_w8 == 0 & cutoff_cat == 2 & functindependent9v2_w8 == 1 & smcquestion_w8 == 0 ~ 14,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent9v2_w8 == 0 & smcquestion_w8 == 1 ~ 15,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent9v2_w8 == 0 & smcquestion_w8 == 0 ~ 16,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent9v2_w8 == 1 & smcquestion_w8 == 1 ~ 17,
      dementiaquestion_w8 == 0 & cutoff_cat == 3 & functindependent9v2_w8 == 1 & smcquestion_w8 == 0 ~ 18))

##Alternative diagnostic groups (cognitive groups with unclear classifications recoded as NA)
studysample2 <- studysample2 %>%
  mutate(
    cognitivegroupsS1_w8 = case_when(
      cognitivegroupsS1_all_w8 == 1 ~ 1,
      cognitivegroupsS1_all_w8 == 2 ~ NA_real_,
      cognitivegroupsS1_all_w8 == 3 ~ 1,
      cognitivegroupsS1_all_w8 == 4 ~ 2,
      cognitivegroupsS1_all_w8 == 5 ~ 1,
      cognitivegroupsS1_all_w8 == 6 ~ 2,
      cognitivegroupsS1_all_w8 == 7 ~ 1,
      cognitivegroupsS1_all_w8 == 8 ~ 1,
      cognitivegroupsS1_all_w8 == 9 ~ NA_real_,
      cognitivegroupsS1_all_w8 == 10 ~ NA_real_,
      cognitivegroupsS1_all_w8 == 11 ~ NA_real_,
      cognitivegroupsS1_all_w8 == 12 ~ NA_real_,
      cognitivegroupsS1_all_w8 == 13 ~ 2,
      cognitivegroupsS1_all_w8 == 14 ~ NA_real_,
      cognitivegroupsS1_all_w8 == 15 ~ NA_real_,
      cognitivegroupsS1_all_w8 == 16 ~ NA_real_,
      cognitivegroupsS1_all_w8 == 17 ~ 3,
      cognitivegroupsS1_all_w8 == 18 ~ 4),
    cognitivegroupsS2_w8 = case_when(
      cognitivegroupsS2_all_w8 == 1 ~ 1,
      cognitivegroupsS2_all_w8 == 2 ~ NA_real_,
      cognitivegroupsS2_all_w8 == 3 ~ 1,
      cognitivegroupsS2_all_w8 == 4 ~ 2,
      cognitivegroupsS2_all_w8 == 5 ~ 1,
      cognitivegroupsS2_all_w8 == 6 ~ 2,
      cognitivegroupsS2_all_w8 == 7 ~ 1,
      cognitivegroupsS2_all_w8 == 8 ~ 1,
      cognitivegroupsS2_all_w8 == 9 ~ NA_real_,
      cognitivegroupsS2_all_w8 == 10 ~ NA_real_,
      cognitivegroupsS2_all_w8 == 11 ~ NA_real_,
      cognitivegroupsS2_all_w8 == 12 ~ NA_real_,
      cognitivegroupsS2_all_w8 == 13 ~ 2,
      cognitivegroupsS2_all_w8 == 14 ~ NA_real_,
      cognitivegroupsS2_all_w8 == 15 ~ NA_real_,
      cognitivegroupsS2_all_w8 == 16 ~ NA_real_,
      cognitivegroupsS2_all_w8 == 17 ~ 3,
      cognitivegroupsS2_all_w8 == 18 ~ 4),
    cognitivegroupsS3_w8 = case_when(
      cognitivegroupsS3_all_w8 == 1 ~ 1,
      cognitivegroupsS3_all_w8 == 2 ~ NA_real_,
      cognitivegroupsS3_all_w8 == 3 ~ 1,
      cognitivegroupsS3_all_w8 == 4 ~ 2,
      cognitivegroupsS3_all_w8 == 5 ~ 1,
      cognitivegroupsS3_all_w8 == 6 ~ 2,
      cognitivegroupsS3_all_w8 == 7 ~ 1,
      cognitivegroupsS3_all_w8 == 8 ~ 1,
      cognitivegroupsS3_all_w8 == 9 ~ NA_real_,
      cognitivegroupsS3_all_w8 == 10 ~ NA_real_,
      cognitivegroupsS3_all_w8 == 11 ~ NA_real_,
      cognitivegroupsS3_all_w8 == 12 ~ NA_real_,
      cognitivegroupsS3_all_w8 == 13 ~ 2,
      cognitivegroupsS3_all_w8 == 14 ~ NA_real_,
      cognitivegroupsS3_all_w8 == 15 ~ NA_real_,
      cognitivegroupsS3_all_w8 == 16 ~ NA_real_,
      cognitivegroupsS3_all_w8 == 17 ~ 3,
      cognitivegroupsS3_all_w8 == 18 ~ 4))

##Alternative diagnostic comparisons
studysample2 <- studysample2 %>%
  mutate(
    D_MCI_v_SMC_NC_S1 = case_when(
      cognitivegroupsS1_w8 == 1 | cognitivegroupsS1_w8 == 2 ~ 1,
      cognitivegroupsS1_w8 == 3 | cognitivegroupsS1_w8 == 4 ~ 0),
    D_MCI_v_NC_S1 = case_when(
      cognitivegroupsS1_w8 == 1 | cognitivegroupsS1_w8 == 2 ~ 1,
      cognitivegroupsS1_w8 == 4 ~ 0),
    MCI_v_D_S1 = case_when(
      cognitivegroupsS1_w8 == 2 ~ 1,
      cognitivegroupsS1_w8 == 1 ~ 0),
    MCI_v_SMC_NC_S1 = case_when(
      cognitivegroupsS1_w8 == 2 ~ 1,
      cognitivegroupsS1_w8 == 3 | cognitivegroupsS1_w8 == 4  ~ 0),
    MCI_v_NC_S1 = case_when(
      cognitivegroupsS1_w8 == 2 ~ 1,
      cognitivegroupsS1_w8 == 4  ~ 0),
    D_v_MCI_SMC_NC_S1 = case_when(
      cognitivegroupsS1_w8 == 1 ~ 1,
      cognitivegroupsS1_w8 == 2 | cognitivegroupsS1_w8 == 3 | cognitivegroupsS1_w8 == 4  ~ 0),
    D_MCI_v_SMC_NC_S2 = case_when(
      cognitivegroupsS2_w8 == 1 | cognitivegroupsS2_w8 == 2 ~ 1,
      cognitivegroupsS2_w8 == 3 | cognitivegroupsS2_w8 == 4 ~ 0),
    D_MCI_v_NC_S2 = case_when(
      cognitivegroupsS2_w8 == 1 | cognitivegroupsS2_w8 == 2 ~ 1,
      cognitivegroupsS2_w8 == 4 ~ 0),
    MCI_v_D_S2 = case_when(
      cognitivegroupsS2_w8 == 2 ~ 1,
      cognitivegroupsS2_w8 == 1 ~ 0),
    MCI_v_SMC_NC_S2 = case_when(
      cognitivegroupsS2_w8 == 2 ~ 1,
      cognitivegroupsS2_w8 == 3 | cognitivegroupsS2_w8 == 4  ~ 0),
    MCI_v_NC_S2 = case_when(
      cognitivegroupsS2_w8 == 2 ~ 1,
      cognitivegroupsS2_w8 == 4  ~ 0),
    D_v_MCI_SMC_NC_S2 = case_when(
      cognitivegroupsS2_w8 == 1 ~ 1,
      cognitivegroupsS2_w8 == 2 | cognitivegroupsS2_w8 == 3 | cognitivegroupsS2_w8 == 4  ~ 0),
    D_MCI_v_SMC_NC_S3 = case_when(
      cognitivegroupsS3_w8 == 1 | cognitivegroupsS3_w8 == 2 ~ 1,
      cognitivegroupsS3_w8 == 3 | cognitivegroupsS3_w8 == 4 ~ 0),
    D_MCI_v_NC_S3 = case_when(
      cognitivegroupsS3_w8 == 1 | cognitivegroupsS3_w8 == 2 ~ 1,
      cognitivegroupsS3_w8 == 4 ~ 0),
    MCI_v_D_S3 = case_when(
      cognitivegroupsS3_w8 == 2 ~ 1,
      cognitivegroupsS3_w8 == 1 ~ 0),
    MCI_v_SMC_NC_S3 = case_when(
      cognitivegroupsS3_w8 == 2 ~ 1,
      cognitivegroupsS3_w8 == 3 | cognitivegroupsS3_w8 == 4  ~ 0),
    MCI_v_NC_S3 = case_when(
      cognitivegroupsS3_w8 == 2 ~ 1,
      cognitivegroupsS3_w8 == 4  ~ 0),
    D_v_MCI_SMC_NC_S3 = case_when(
      cognitivegroupsS3_w8 == 1 ~ 1,
      cognitivegroupsS3_w8 == 2 | cognitivegroupsS3_w8 == 3 | cognitivegroupsS3_w8 == 4  ~ 0))
