#Completed in R version 4.2.1 (2022-06-23 ucrt) [platform: x86_64-w64-mingw32]
#Including the following packages:
library(DescTools) #package version 0.99.49
library(pROC) #package version 1.18.0

#3.2.1. Maximum Score for Verbal Fluency

##Custom function to calculate Efron's R square value (to measure model fit)
modelfit <- function(predictor, outcome) {
  model <- glm(outcome ~ predictor + sample_primary$wreg10_w8 + sample_primary$recall10_w8, family = "binomial")
  PseudoR2(model, "Efron")}

##Add fluency values with different maximum scores
sample_primary$fluency60 <- pmin(sample_primary$fluency_w8, 60)
sample_primary$fluency40 <- pmin(sample_primary$fluency_w8, 40)
sample_primary$fluency30 <- pmin(sample_primary$fluency_w8, 30)
sample_primary$fluency20 <- pmin(sample_primary$fluency_w8, 20)
sample_primary$fluency10 <- pmin(sample_primary$fluency_w8, 10)

## Tests of different maximum verbal fluency scores (R squared value)   
Table_S3a <- rbind(
  data.frame(t(c(
    modelfit(sample_primary$fluency_w8, sample_primary$D_MCI_v_SMC_NC), 
    modelfit(sample_primary$fluency60, sample_primary$D_MCI_v_SMC_NC), 
    modelfit(sample_primary$fluency40, sample_primary$D_MCI_v_SMC_NC), 
    modelfit(sample_primary$fluency30, sample_primary$D_MCI_v_SMC_NC), 
    modelfit(sample_primary$fluency20, sample_primary$D_MCI_v_SMC_NC), 
    modelfit(sample_primary$fluency10, sample_primary$D_MCI_v_SMC_NC)))),
  data.frame(t(c(
    modelfit(sample_primary$fluency_w8, sample_primary$D_MCI_v_NC), 
    modelfit(sample_primary$fluency60, sample_primary$D_MCI_v_NC), 
    modelfit(sample_primary$fluency40, sample_primary$D_MCI_v_NC), 
    modelfit(sample_primary$fluency30, sample_primary$D_MCI_v_NC), 
    modelfit(sample_primary$fluency20, sample_primary$D_MCI_v_NC), 
    modelfit(sample_primary$fluency10, sample_primary$D_MCI_v_NC)))),
  data.frame(t(c(
    modelfit(sample_primary$fluency_w8, sample_primary$MCI_v_D), 
    modelfit(sample_primary$fluency60, sample_primary$MCI_v_D), 
    modelfit(sample_primary$fluency40, sample_primary$MCI_v_D), 
    modelfit(sample_primary$fluency30, sample_primary$MCI_v_D), 
    modelfit(sample_primary$fluency20, sample_primary$MCI_v_D), 
    modelfit(sample_primary$fluency10, sample_primary$MCI_v_D)))),
  data.frame(t(c(
    modelfit(sample_primary$fluency_w8, sample_primary$MCI_v_SMC_NC), 
    modelfit(sample_primary$fluency60, sample_primary$MCI_v_SMC_NC), 
    modelfit(sample_primary$fluency40, sample_primary$MCI_v_SMC_NC), 
    modelfit(sample_primary$fluency30, sample_primary$MCI_v_SMC_NC), 
    modelfit(sample_primary$fluency20, sample_primary$MCI_v_SMC_NC), 
    modelfit(sample_primary$fluency10, sample_primary$MCI_v_SMC_NC)))),
  data.frame(t(c(
    modelfit(sample_primary$fluency_w8, sample_primary$MCI_v_NC), 
    modelfit(sample_primary$fluency60, sample_primary$MCI_v_NC), 
    modelfit(sample_primary$fluency40, sample_primary$MCI_v_NC), 
    modelfit(sample_primary$fluency30, sample_primary$MCI_v_NC), 
    modelfit(sample_primary$fluency20, sample_primary$MCI_v_NC), 
    modelfit(sample_primary$fluency10, sample_primary$MCI_v_NC)))),
  data.frame(t(c(
    modelfit(sample_primary$fluency_w8, sample_primary$D_v_MCI_SMC_NC), 
    modelfit(sample_primary$fluency60, sample_primary$D_v_MCI_SMC_NC), 
    modelfit(sample_primary$fluency40, sample_primary$D_v_MCI_SMC_NC), 
    modelfit(sample_primary$fluency30, sample_primary$D_v_MCI_SMC_NC), 
    modelfit(sample_primary$fluency20, sample_primary$D_v_MCI_SMC_NC), 
    modelfit(sample_primary$fluency10, sample_primary$D_v_MCI_SMC_NC)))))
Table_S3a <- round(Table_S3a, 3)

## Tests of different maximum verbal fluency scores (AUC value)
Table_S3b <- rbind(
  data.frame(t(c(
    roc(sample_primary$D_MCI_v_SMC_NC, sample_primary$fluency_w8, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_MCI_v_SMC_NC, sample_primary$fluency60, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_MCI_v_SMC_NC, sample_primary$fluency40, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_MCI_v_SMC_NC, sample_primary$fluency30, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_MCI_v_SMC_NC, sample_primary$fluency20, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_MCI_v_SMC_NC, sample_primary$fluency10, direction=">", levels=c(0, 1))[["auc"]][1]))),
  data.frame(t(c(
    roc(sample_primary$D_MCI_v_NC, sample_primary$fluency_w8, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_MCI_v_NC, sample_primary$fluency60, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_MCI_v_NC, sample_primary$fluency40, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_MCI_v_NC, sample_primary$fluency30, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_MCI_v_NC, sample_primary$fluency20, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_MCI_v_NC, sample_primary$fluency10, direction=">", levels=c(0, 1))[["auc"]][1]))),
  data.frame(t(c(
    roc(sample_primary$MCI_v_D, sample_primary$fluency_w8, direction="<", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_D, sample_primary$fluency60, direction="<", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_D, sample_primary$fluency40, direction="<", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_D, sample_primary$fluency30, direction="<", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_D, sample_primary$fluency20, direction="<", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_D, sample_primary$fluency10, direction="<", levels=c(0, 1))[["auc"]][1]))),
  data.frame(t(c(
    roc(sample_primary$MCI_v_SMC_NC, sample_primary$fluency_w8, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_SMC_NC, sample_primary$fluency60, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_SMC_NC, sample_primary$fluency40, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_SMC_NC, sample_primary$fluency30, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_SMC_NC, sample_primary$fluency20, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_SMC_NC, sample_primary$fluency10, direction=">", levels=c(0, 1))[["auc"]][1]))),
  data.frame(t(c(
    roc(sample_primary$MCI_v_NC, sample_primary$fluency_w8, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_NC, sample_primary$fluency60, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_NC, sample_primary$fluency40, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_NC, sample_primary$fluency30, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_NC, sample_primary$fluency20, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$MCI_v_NC, sample_primary$fluency10, direction=">", levels=c(0, 1))[["auc"]][1]))),
  data.frame(t(c(
    roc(sample_primary$D_v_MCI_SMC_NC, sample_primary$fluency_w8, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_v_MCI_SMC_NC, sample_primary$fluency60, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_v_MCI_SMC_NC, sample_primary$fluency40, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_v_MCI_SMC_NC, sample_primary$fluency30, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_v_MCI_SMC_NC, sample_primary$fluency20, direction=">", levels=c(0, 1))[["auc"]][1], 
    roc(sample_primary$D_v_MCI_SMC_NC, sample_primary$fluency10, direction=">", levels=c(0, 1))[["auc"]][1])))
)
Table_S3b <- round(Table_S3b, 3)

