#Completed in R version 4.2.1 (2022-06-23 ucrt) [platform: x86_64-w64-mingw32]
#Including the following package:
library(AROC) #package version 1.0-4

#3.5. Table S6

##Custom function for p-value rounding
p_val <- function(x) {
  return(if(x<0.001){"<0.001"} else{round(x, 3)} )}

##Data preparation (AROC package requires a dataframe with no missing values, and categorical variables should be coded as factors) 
AROC_data1 <- as.data.frame(sample_primary)
AROC_data1$agecat_w8 <- as.factor(AROC_data1$agecat_w8)
AROC_data1$educationcat_w8 <- as.factor(AROC_data1$educationcat_w8)
AROC_data1$female <- as.factor(AROC_data1$female)
AROC_data1$country <- as.factor(AROC_data1$country)
AROC_data1$D_MCI_v_SMC_NC <- as.factor(AROC_data1$D_MCI_v_SMC_NC)
AROC_data1$D_MCI_v_NC <- as.factor(AROC_data1$D_MCI_v_NC)
AROC_data1$MCI_v_D <- as.factor(AROC_data1$MCI_v_D)
AROC_data1$MCI_v_SMC_NC <- as.factor(AROC_data1$MCI_v_SMC_NC)
AROC_data1$MCI_v_NC <- as.factor(AROC_data1$MCI_v_NC)
AROC_data1$D_v_MCI_SMC_NC <- as.factor(AROC_data1$D_v_MCI_SMC_NC)
AROC_data1$sharecog_w8 <- as.numeric(AROC_data1$sharecog_w8)
AROC_data2 <- AROC_data1[!is.na(AROC_data1$D_MCI_v_NC),]
AROC_data3 <- AROC_data1[!is.na(AROC_data1$MCI_v_D),]
AROC_data4 <- AROC_data1[!is.na(AROC_data1$MCI_v_SMC_NC),]
AROC_data5 <- AROC_data1[!is.na(AROC_data1$MCI_v_NC),]

##Calculation of AROC curves (with confidence intervals)
set.seed(04092023) #to produce the same bootstrap confidence intervals each time
roc1a <- AROC.sp (formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
                group = "D_MCI_v_SMC_NC", tag.healthy = 1, data = AROC_data1, B = 1000) #confidence from 1000 bootstrap resamples
roc2a <- AROC.sp (formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
                group = "D_MCI_v_NC", tag.healthy = 1, data = AROC_data2, B = 1000)
roc3a <- AROC.sp (formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
                group = "MCI_v_D", tag.healthy = 0, data = AROC_data3, B = 1000)
roc4a <- AROC.sp (formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
                group = "MCI_v_SMC_NC", tag.healthy = 1, data = AROC_data4, B = 1000)
roc5a <- AROC.sp (formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
                group = "MCI_v_NC", tag.healthy = 1, data = AROC_data5, B = 1000)
roc6a <- AROC.sp (formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
                group = "D_v_MCI_SMC_NC", tag.healthy = 1, data = AROC_data1, B = 1000)

##Table S6
Table_S6 <- 
  data.frame(
    AAUC = c(
      paste0(round(roc1a[["AUC"]][["est"]], 2), " (", round(roc1a[["AUC"]][["ql"]], 2), "–", round(roc1a[["AUC"]][["qh"]], 2),")"),
      paste0(round(roc2a[["AUC"]][["est"]], 2), " (", round(roc2a[["AUC"]][["ql"]], 2), "–", round(roc2a[["AUC"]][["qh"]], 2),")"),
      paste0(round(roc3a[["AUC"]][["est"]], 2), " (", round(roc3a[["AUC"]][["ql"]], 2), "–", round(roc3a[["AUC"]][["qh"]], 2),")"),
      paste0(round(roc4a[["AUC"]][["est"]], 2), " (", round(roc4a[["AUC"]][["ql"]], 2), "–", round(roc4a[["AUC"]][["qh"]], 2),")"),
      paste0(round(roc5a[["AUC"]][["est"]], 2), " (", round(roc5a[["AUC"]][["ql"]], 2), "–", round(roc5a[["AUC"]][["qh"]], 2),")"),
      paste0(round(roc6a[["AUC"]][["est"]], 2), " (", round(roc6a[["AUC"]][["ql"]], 2), "–", round(roc6a[["AUC"]][["qh"]], 2),")")),
    intercept = c(
      round(summary(roc1a$fit.h)[["coefficients"]][1], 2),
      round(summary(roc2a$fit.h)[["coefficients"]][1], 2),
      round(summary(roc3a$fit.h)[["coefficients"]][1], 2),
      round(summary(roc4a$fit.h)[["coefficients"]][1], 2),
      round(summary(roc5a$fit.h)[["coefficients"]][1], 2),
      round(summary(roc6a$fit.h)[["coefficients"]][1], 2)),
    age_mid = c(
      paste0(round(summary(roc1a$fit.h)[["coefficients"]][2], 2), " (", p_val(summary(roc1a$fit.h)[["coefficients"]][2,4]), ")"),
      paste0(round(summary(roc2a$fit.h)[["coefficients"]][2], 2), " (", p_val(summary(roc2a$fit.h)[["coefficients"]][2,4]), ")"),
      paste0(round(summary(roc3a$fit.h)[["coefficients"]][2], 2), " (", p_val(summary(roc3a$fit.h)[["coefficients"]][2,4]), ")"),
      paste0(round(summary(roc4a$fit.h)[["coefficients"]][2], 2), " (", p_val(summary(roc4a$fit.h)[["coefficients"]][2,4]), ")"),
      paste0(round(summary(roc5a$fit.h)[["coefficients"]][2], 2), " (", p_val(summary(roc5a$fit.h)[["coefficients"]][2,4]), ")"),
      paste0(round(summary(roc6a$fit.h)[["coefficients"]][2], 2), " (", p_val(summary(roc6a$fit.h)[["coefficients"]][2,4]), ")")),
    age_high = c(
      paste0(round(summary(roc1a$fit.h)[["coefficients"]][3], 2), " (", p_val(summary(roc1a$fit.h)[["coefficients"]][3,4]), ")"),
      paste0(round(summary(roc2a$fit.h)[["coefficients"]][3], 2), " (", p_val(summary(roc2a$fit.h)[["coefficients"]][3,4]), ")"),
      paste0(round(summary(roc3a$fit.h)[["coefficients"]][3], 2), " (", p_val(summary(roc3a$fit.h)[["coefficients"]][3,4]), ")"),
      paste0(round(summary(roc4a$fit.h)[["coefficients"]][3], 2), " (", p_val(summary(roc4a$fit.h)[["coefficients"]][3,4]), ")"),
      paste0(round(summary(roc5a$fit.h)[["coefficients"]][3], 2), " (", p_val(summary(roc5a$fit.h)[["coefficients"]][3,4]), ")"),
      paste0(round(summary(roc6a$fit.h)[["coefficients"]][3], 2), " (", p_val(summary(roc6a$fit.h)[["coefficients"]][3,4]), ")")),
    education_mid = c(
      paste0(round(summary(roc1a$fit.h)[["coefficients"]][4], 2), " (", p_val(summary(roc1a$fit.h)[["coefficients"]][4,4]), ")"),
      paste0(round(summary(roc2a$fit.h)[["coefficients"]][4], 2), " (", p_val(summary(roc2a$fit.h)[["coefficients"]][4,4]), ")"),
      paste0(round(summary(roc3a$fit.h)[["coefficients"]][4], 2), " (", p_val(summary(roc3a$fit.h)[["coefficients"]][4,4]), ")"),
      paste0(round(summary(roc4a$fit.h)[["coefficients"]][4], 2), " (", p_val(summary(roc4a$fit.h)[["coefficients"]][4,4]), ")"),
      paste0(round(summary(roc5a$fit.h)[["coefficients"]][4], 2), " (", p_val(summary(roc5a$fit.h)[["coefficients"]][4,4]), ")"),
      paste0(round(summary(roc6a$fit.h)[["coefficients"]][4], 2), " (", p_val(summary(roc6a$fit.h)[["coefficients"]][4,4]), ")")),
    education_high = c(
      paste0(round(summary(roc1a$fit.h)[["coefficients"]][5], 2), " (", p_val(summary(roc1a$fit.h)[["coefficients"]][5,4]), ")"),
      paste0(round(summary(roc2a$fit.h)[["coefficients"]][5], 2), " (", p_val(summary(roc2a$fit.h)[["coefficients"]][5,4]), ")"),
      paste0(round(summary(roc3a$fit.h)[["coefficients"]][5], 2), " (", p_val(summary(roc3a$fit.h)[["coefficients"]][5,4]), ")"),
      paste0(round(summary(roc4a$fit.h)[["coefficients"]][5], 2), " (", p_val(summary(roc4a$fit.h)[["coefficients"]][5,4]), ")"),
      paste0(round(summary(roc5a$fit.h)[["coefficients"]][5], 2), " (", p_val(summary(roc5a$fit.h)[["coefficients"]][5,4]), ")"),
      paste0(round(summary(roc6a$fit.h)[["coefficients"]][5], 2), " (", p_val(summary(roc6a$fit.h)[["coefficients"]][5,4]), ")")),
    female = c(
      paste0(round(summary(roc1a$fit.h)[["coefficients"]][6], 2), " (", p_val(summary(roc1a$fit.h)[["coefficients"]][6,4]), ")"),
      paste0(round(summary(roc2a$fit.h)[["coefficients"]][6], 2), " (", p_val(summary(roc2a$fit.h)[["coefficients"]][6,4]), ")"),
      paste0(round(summary(roc3a$fit.h)[["coefficients"]][6], 2), " (", p_val(summary(roc3a$fit.h)[["coefficients"]][6,4]), ")"),
      paste0(round(summary(roc4a$fit.h)[["coefficients"]][6], 2), " (", p_val(summary(roc4a$fit.h)[["coefficients"]][6,4]), ")"),
      paste0(round(summary(roc5a$fit.h)[["coefficients"]][6], 2), " (", p_val(summary(roc5a$fit.h)[["coefficients"]][6,4]), ")"),
      paste0(round(summary(roc6a$fit.h)[["coefficients"]][6], 2), " (", p_val(summary(roc6a$fit.h)[["coefficients"]][6,4]), ")")),
    country_sig = c(
      sum(as.numeric(summary(roc1a$fit.h)[["coefficients"]][7:24,4]) <= 0.05),
      sum(as.numeric(summary(roc2a$fit.h)[["coefficients"]][7:24,4]) <= 0.05),
      sum(as.numeric(summary(roc3a$fit.h)[["coefficients"]][7:24,4]) <= 0.05),
      sum(as.numeric(summary(roc4a$fit.h)[["coefficients"]][7:24,4]) <= 0.05),
      sum(as.numeric(summary(roc5a$fit.h)[["coefficients"]][7:24,4]) <= 0.05),
      sum(as.numeric(summary(roc6a$fit.h)[["coefficients"]][7:24,4]) <= 0.05)),
    r2_value = c(
      round(summary(roc1a$fit.h)[["r.squared"]], 3),
      round(summary(roc2a$fit.h)[["r.squared"]], 3),
      round(summary(roc3a$fit.h)[["r.squared"]], 3),
      round(summary(roc4a$fit.h)[["r.squared"]], 3),
      round(summary(roc5a$fit.h)[["r.squared"]], 3),
      round(summary(roc6a$fit.h)[["r.squared"]], 3))
    )

##Results for countries with statistically significant results
summary(roc3a$fit.h) #country 18 = Denmark MCI_v_D -4.77 (p=0.029)
summary(roc4a$fit.h) #country 16 = Italy MCI_v_SMC_NC -3.16 (p=0.024)
summary(roc5a$fit.h) #country 16 = Italy MCI_v_NC -3.16 (p=0.024)
summary(roc6a$fit.h) #country 18 = Denmark D_v_MCI_SMC_NC -4.77 (p=0.029)
